package de.fitko.fitconnect.api.services.destination;

import de.fitko.fitconnect.api.domain.model.destination.Destination;
import de.fitko.fitconnect.api.domain.model.jwk.JWK;
import de.fitko.fitconnect.api.domain.model.submission.Submission;
import de.fitko.fitconnect.api.exceptions.RestApiException;

import java.util.UUID;

/**
 * A service that provides access to a {@link Submission}s {@link Destination} and its public encryption key
 * via the FIT-Connect REST-API.
 */
public interface DestinationService {

    /**
     * Get the {@link Destination} by id.
     *
     * @param destinationID unique destination identifier
     * @return the destination
     *
     * @throws RestApiException if an error occurred
     */
    Destination getDestination(UUID destinationID) throws RestApiException;

    /**
     * Get the public encryption {@link JWK} fo a given destination.
     *
     * @param destinationID unique destination identifier
     * @param keyId the keyId property of the public key
     * @return the {@link JWK}
     *
     * @throws RestApiException if an error occurred
     */
    JWK getEncryptionKey(UUID destinationID, String keyId) throws RestApiException;
}
