package de.fitko.fitconnect.api.services.events;

import de.fitko.fitconnect.api.domain.model.event.EventLog;
import de.fitko.fitconnect.api.domain.model.submission.Submission;

import java.util.UUID;

/**
 * A service that provides access to the {@link Submission}s {@link EventLog} via the FIT-Connect REST-API.
 * Every event is a recorded step within the process of sending a submission or a case.
 * Events are encoded as security event tokens (SET).
 *
 * @see <a href="https://docs.fitko.de/fit-connect/docs/getting-started/event-log/events">Event Documentation</a>
 */
public interface EventLogService {

    /**
     * Get the {@link EventLog} by caseId.
     *
     * @param caseId unique case identifier
     * @return
     */
    EventLog getEventLog(UUID caseId);

    /**
     * Send an event for a given caseId.
     *
     * @param caseId unique case identifier
     * @param signedAndSerializedSET the serialised and signed event as SET string
     */
    void sendEvent(UUID caseId, String signedAndSerializedSET);
}
