package de.fitko.fitconnect.client.factory;

import de.fitko.fitconnect.api.config.ApplicationConfig;
import org.yaml.snakeyaml.Yaml;
import org.yaml.snakeyaml.constructor.Constructor;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

public class ApplicationConfigLoader {

    private ApplicationConfigLoader(){}

    /**
     * Load ApplicationConfig from path.
     *
     * @param configPath path to config file
     *
     * @return ApplicationConfig
     * @throws IOException if the default config file could not be loaded
     */
    public static ApplicationConfig loadConfig(final Path configPath) throws IOException {
        return loadConfig(Files.readString(configPath));
    }

    /**
     * Load ApplicationConfig from string.
     *
     * @param configYaml string of the yaml config file
     *
     * @return ApplicationConfig
     */
    public static ApplicationConfig loadConfig(final String configYaml) {
        final Constructor constructor = new Constructor(ApplicationConfig.class);
        final Yaml yaml = new Yaml(constructor);
        return yaml.load(configYaml);
    }
}
