package de.fitko.fitconnect.client.factory;

import de.fitko.fitconnect.api.config.ApplicationConfig;
import de.fitko.fitconnect.api.config.Environment;
import de.fitko.fitconnect.api.config.SenderConfig;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Objects;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.jupiter.api.Assertions.assertNotNull;

class ApplicationConfigLoaderTest {

    @Test
    void testLoadMissingConfigFile(){
        Assertions.assertThrows(IOException.class, () -> ApplicationConfigLoader.loadConfig(Path.of("/no/path")));
    }

    @Test
    void testLoadTestConfigFromString() throws IOException {

        // Given
        final String testConfigYaml = getResourceAsString("test-config.yml");

        final Environment devEnv = new Environment(
                "https://auth-testing.fit-connect.fitko.dev",
                "https://submission-api-testing.fit-connect.fitko.dev",
                true
        );

        final SenderConfig senderConfig = new SenderConfig("1", "123");

        // When
        final ApplicationConfig testConfig = ApplicationConfigLoader.loadConfig(testConfigYaml);

        // Then
        assertNotNull(testConfig);
        assertThat(testConfig.getCurrentEnvironment(), equalTo(devEnv));
        assertThat(testConfig.getSenderConfig(), equalTo(senderConfig));
    }

    private String getResourceAsString(final String name) throws IOException {
        final ClassLoader classLoader = getClass().getClassLoader();
        final File file = new File(Objects.requireNonNull(classLoader.getResource(name)).getFile());
        return Files.readString(file.toPath());
    }
}