package de.fitko.fitconnect.client.factory;

import de.fitko.fitconnect.api.config.*;
import org.junit.jupiter.api.Test;

import java.util.Map;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertThrows;

class ClientFactoryTest {

    @Test
    void testMissingConfiguration() {
        assertThrows(IllegalStateException.class, () -> ClientFactory.senderClient());
        assertThrows(IllegalStateException.class, () -> ClientFactory.subscriberClient());
    }

    @Test
    void testSenderClientConstruction() {

        final var envName = new EnvironmentName("DEV");
        final var environments = Map.of(envName, new Environment("https://auth", "", true));

        final var sender = new SenderConfig("123", "abc");

        final var resourcePaths = new ResourcePaths();
        resourcePaths.setAuthTokenPath("/token");

        final var senderConfig = ApplicationConfig.builder()
                .httpProxyHost("https://proxy.fitco.de")
                .httpProxyPort(0)
                .environments(environments)
                .senderConfig(sender)
                .resourcePaths(resourcePaths)
                .activeEnvironment(envName)
                .build();
        senderConfig.setMetadataSchemaPath("src/test/resources/metadata_schema.json");
        senderConfig.setPrivateSigningKeyPath("src/test/resources/private_test_signing_key.json");

        assertNotNull(ClientFactory.senderClient(senderConfig));
    }

    @Test
    void testSubscriberClientConstruction() {

        final var envName = new EnvironmentName("DEV");
        final var environments = Map.of(envName, new Environment("https://auth", "", true));

        final var resourcePaths = new ResourcePaths();
        resourcePaths.setAuthTokenPath("/token");

        final var subscriber = SubscriberConfig.builder()
                .clientSecret("123")
                .clientSecret("abc")
                .privateDecryptionKeyPath("src/test/resources/private_decryption_test_key.json")
                .build();

        final var subscriberConfig = ApplicationConfig.builder()
                .httpProxyHost("https://proxy.fitco.de")
                .httpProxyPort(0)
                .environments(environments)
                .subscriberConfig(subscriber)
                .resourcePaths(resourcePaths)
                .activeEnvironment(envName)
                .privateSigningKeyPath("src/test/resources/private_test_signing_key.json")
                .metadataSchemaPath("src/test/resources/metadata_schema.json")
                .build();

        assertNotNull(ClientFactory.subscriberClient(subscriberConfig));
    }
}