package de.fitko.fitconnect.core.http;

import de.fitko.fitconnect.core.util.Strings;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.client.ClientHttpRequestInterceptor;
import org.springframework.http.client.SimpleClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

import java.net.InetSocketAddress;
import java.net.Proxy;
import java.util.List;

public class ProxyConfig {

    private static final Logger logger = LoggerFactory.getLogger(ProxyConfig.class);

    private final String host;
    private final int port;

    public ProxyConfig(final String host, final int port) {
        this.host = host;
        this.port = port;
    }

    public RestTemplate proxyRestTemplate() {
        if (!hasProxySet()) {
            logger.info("No proxy configured");
            final RestTemplate restTemplate = new RestTemplate();
            setLoggingInterceptor(restTemplate);
            return restTemplate;
        }

        logger.info("Using proxy {}", this);
        final var requestFactory = new SimpleClientHttpRequestFactory();
        final var proxy = new Proxy(Proxy.Type.HTTP, new InetSocketAddress(host, port));
        requestFactory.setProxy(proxy);
        final ProxyRestTemplate proxyRestTemplate = new ProxyRestTemplate(requestFactory);
        setLoggingInterceptor(proxyRestTemplate);
        return proxyRestTemplate;
    }

    private void setLoggingInterceptor(final RestTemplate restTemplate) {
        final List<ClientHttpRequestInterceptor> interceptors = restTemplate.getInterceptors();
        interceptors.add(new ApiRequestInterceptor());
        restTemplate.setInterceptors(interceptors);
    }

    public boolean hasProxySet() {
        return !Strings.isNullOrEmpty(host) && port > 0;
    }

    @Override
    public String toString() {
        return String.format("ProxyConfig {host='%s', port=%d}", host, port);
    }
}