package de.fitko.fitconnect.core.crypto;

import de.fitko.fitconnect.api.services.crypto.MessageDigestService;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

class HashServiceTest {

    private MessageDigestService underTest;

    @BeforeEach
    public void setup() throws NoSuchAlgorithmException {
        final MessageDigest SHA_512 = MessageDigest.getInstance(HashService.DEFAULT_ALGORITHM);
        underTest = new HashService(SHA_512);
    }

    @Test
    void createHash() throws IOException {

        // Given
        final byte[] expectedHash = {-13, -77, -85, 62, 99, 81, -30, 91, 92, 24, -126, -66, -88, -45, 126, -6, -35,
                -64, -22, 114, -65, 21, 59, -80, 103, 104, -113, 119, 90, 38, -127, 13, 50, -75, 79, 1, 75, -15, -50,
                -68, 127, -23, 48, 66, -40, 91, 24, -75, -76, 83, -29, 34, -47, 84, -68, 85, -43, -52, 39, 84, -80,
                -33, -76, -78};

        final byte[] exampleFileContent = getExampleFileContent("/attachment.pdf");

        // When
        final byte[] hash = underTest.createHash(exampleFileContent);

        // Then
        assertThat(expectedHash, equalTo(hash));
    }

    @Test
    void verify() throws IOException {
        // Given
        final byte[] expectedHash = {-13, -77, -85, 62, 99, 81, -30, 91, 92, 24, -126, -66, -88, -45, 126, -6, -35,
                -64, -22, 114, -65, 21, 59, -80, 103, 104, -113, 119, 90, 38, -127, 13, 50, -75, 79, 1, 75, -15, -50,
                -68, 127, -23, 48, 66, -40, 91, 24, -75, -76, 83, -29, 34, -47, 84, -68, 85, -43, -52, 39, 84, -80,
                -33, -76, -78};

        final byte[] exampleFileContent = getExampleFileContent("/attachment.pdf");

        // When
        final boolean hashesAreEqual = underTest.verify(expectedHash, exampleFileContent);

        // Then
        assertTrue(hashesAreEqual);
    }

    @Test
    void toHexString() {
        // Given
        final byte[] data = "some data".getBytes(StandardCharsets.UTF_8);
        final var expectedHexString = "736f6d652064617461";

        // When
        final String hexString = underTest.toHexString(data);

        // Then
        assertEquals(expectedHexString, hexString);
    }

    @Test
    void fromHexString() {
        // Given
        final var hexString = "736f6d652064617461";

        // When
        final byte[] bytes = underTest.fromHexString(hexString);

        // Then
        assertEquals("some data", new String(bytes, StandardCharsets.UTF_8));
    }

    private byte[] getExampleFileContent(final String path) throws IOException {
        return HashService.class.getResourceAsStream(path).readAllBytes();
    }

}